#
# spec file for package s3backer
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           s3backer
Version:        1.6.3
Release:        bp154.1.23
Summary:        FUSE-based single file backing store via Amazon S3
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://github.com/archiecobbs/%{name}
Source:         https://s3.amazonaws.com/archie-public/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  fuse-devel >= 2.5
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
%if 0%{?suse_version} >= 1100
BuildRequires:  libcurl-devel >= 7.16.2
BuildRequires:  libopenssl-devel
%else
BuildRequires:  curl-devel >= 7.16.2
BuildRequires:  openssl-devel
%endif
%if 0%{?suse_version} < 1000 || 0%{?fedora_version} != 0 || 0%{?centos_version} != 0
BuildRequires:  expat
%else
BuildRequires:  libexpat-devel
%endif

%description
s3backer is a filesystem that contains a single file backed by the Amazon
Simple Storage Service (Amazon S3).  As a filesystem, it is very simple:
it provides a single normal file having a fixed size.  Underneath, the
file is divided up into blocks, and the content of each block is stored
in a unique Amazon S3 object.  In other words, what s3backer provides is
really more like an S3-backed virtual hard disk device, rather than a
filesystem.

In typical usage, a `normal' filesystem is mounted on top of the file
exported by the s3backer filesystem using a loopback mount (or disk image
mount on Mac OS X).

%prep
%setup -q

%build
export SUSE_ASNEEDED=0
%configure
%make_build

%install
make install DESTDIR='%{buildroot}'
install -m 0644 COPYING %{buildroot}%{_docdir}/%{name}/
rm -f %{buildroot}%{_docdir}/%{name}/INSTALL

%files
%{_bindir}/*
%{_mandir}/man1/*
%{_docdir}/%{name}

%changelog
* Wed Oct 27 2021 Archie Cobbs <archie.cobbs@gmail.com>
- Run spec-cleaner on spec file
* Sat Oct  2 2021 Archie Cobbs <archie.cobbs@gmail.com>
- Upgrade to release 1.6.3
  + Fixed bug with `--listBlocks' threads doing redundant overlapping queries
  + Refactor to support multiple different compression algorithms
  + Fixed mutex handling bug in block cache (issue #152)
  + Release mutexs prior to destruction (issue #151)
  + Fixed use-after-free bug in XML parser (pr #154)
* Mon Jun 14 2021 Archie Cobbs <archie.cobbs@gmail.com>
- Upgrade to release 1.6.2
  + Require test directory to be absolute unless `-f' flag given (issue #143)
  + Show HTTP error response payload content when `--debug-http' flag given
  + List blocks in the background; added `--listBlocksThreads' (issue #24)
  + Don't let IAM credentials expire while listing blocks (issue #146)
  + Fixed bug parsing "--configFile" inside comma-separated option list
* Wed Dec 30 2020 Archie Cobbs <archie.cobbs@gmail.com>
- Upgrade to release 1.6.1
  + Fixed integer overflow bug setting "x-amz-meta-s3backer-filesize" (issue #141)
* Wed Dec 23 2020 Archie Cobbs <archie.cobbs@gmail.com>
- Upgrade to release 1.6.0
  + Added `--sse-key-id' flag (issue #137)
  + Log a more useful error message when IAM credentials not found (issue #136)
  + Warn on startup if disk space is insufficient for disk cache (issue #138)
  + Added zero block cache to better handle fstrim operations (issue #139)
* Fri Oct 30 2020 Archie Cobbs <archie.cobbs@gmail.com>
- Upgrade to release 1.5.6
  + Fixed phantom write error when server-side-encryption used (issue #135)
  + Allow bucket names with "subdirectory" for prefix (issue #130)
  + Added `--configFile' flag (issue #129)
  + Added `--accessKeyEnv' flag (issue #128)
  + Removed deprecated `--rrs' flag
* Sat Aug 22 2020 Archie Cobbs <archie.cobbs@gmail.com>
- Upgrade to release 1.5.5
  + Added `--no-vhost' flag (issue #117)
  + Added `--blockCacheNumProtected' flag (pr #119)
  + Added `--test-errors', `--test-delays', and `--test-discard'
  + Disallow stream encryption ciphers (issue #123)
* Tue Oct  8 2019 <archie.cobbs@gmail.com>
- Upgrade to release 1.5.4
  + Only set "x-amz-server-side-encryption" header with PUT requests (issue #116)
  + Don't kill IAM thread unless actually started (issue #115).
* Fri Aug  9 2019 <archie.cobbs@gmail.com>
- Update to release 1.5.3
  + Fixed bug where IAM update thread was killed after fork (issue #115)
  + Fixed use-after-free bug in block_cache_verified() (issue #113)
  + Fixed use-after-free bug when updating IAM credentials (pr #114)
  + Fixed bug in test mode that was causing bogus I/O errors
* Tue Jul  9 2019 <archie.cobbs@gmail.com>
- Update to release 1.5.2
  + Fixed bug where block cache would not work when run in the background (issue #112)
  + Fixed bug where we were not parsing HTTP headers case-insensitively (pr #11)
  + Bail out during `--listBlocks' if we see an object name past our block range
  + Added `--blockHashPrefix' flag (issue #80)
* Mon Apr 15 2019 archie.cobbs@gmail.com
- Update to release 1.5.1
  + Fixed a few places where fixed-sized buffers were too small (issue #108)
  + Don't claim cache hit if partial write required reading the block (pr #103)
  + Exit process with error code if s3backer store setup fails at startup
  + Reset statistics if stats file is unlinked (issue #106)
* Sat Jun  9 2018 archie.cobbs@gmail.com
- Update to release 1.5.0
  + Add support for recovering dirty blocks in the disk cache (issue #87)
  + Replaced boolean 'mounted' flag with a unique 32-bit mount token (issue #87)
  + Wait for min_write_delay before access after write error (issue #76)
  + Configure TCP keep-alive on HTTP connections (issue #78)
  + Added support for server side encryption (pull #81)
* Wed Feb  1 2017 archie.cobbs@gmail.com
- Update to release 1.4.4
  + Added `--defaultContentEncoding' for non-compliant backends (issue #68)
  + Fixed auth bug when prefix contains URL-encodable char (issue #69)
  + Remove restriction preventing streaming encryption modes (issue #70)
* Mon Jul 25 2016 archie.cobbs@gmail.com
- Update to release 1.4.3
  + Add support for STANDARD_IA storage class (issue #59)
  + Set "Accept-Encoding" header appropriately (issue #48)
  + Fix build issue with OpenSSL 1.1.0 (issue #64)
* Tue Sep  1 2015 archie@dellroad.org
- Update to release 1.4.2
  + Update license to fix OpenSSL vs. GPL conflict
* Mon May  4 2015 archie@dellroad.org
- Update to release 1.4.1
  + Fix use-after-free bug configuring base URL (github issue #44)
* Fri Apr 17 2015 archie@dellroad.org
- Update to release 1.4.0
  + Added support for authentication version 4 (issue #51)
  + Added support for credentials via IAM role from EC2 meta-data (issue #48)
  + Fixed bug where `--erase' did not clear the mounted flag
  + Moved from Google project hosting to GitHub
  + Fixed compile problem on FreeBSD
* Thu Jul 18 2013 archie@dellroad.org
- Update to version 1.3.7
  + Add `--keyLength' for overriding generated encryption key length
* Tue Jul 16 2013 archie@dellroad.org
- Update to version 1.3.6
  + Fix use of MAX_HOST_NAME in http_io.c (issue #42)
  + Fix encryption key generation bug (on some systems)
* Wed May 29 2013 archie@dellroad.org
- Update to version 1.3.5
  + Check for duplicate mount at startup (issue #10)
  + Minor spec file cleanups
* Wed Apr  3 2013 archie@dellroad.org
- Update to version 1.3.4
  + Add support for fallocate(2)
* Wed Jan 23 2013 archie@dellroad.org
- Fix License to use SPDX format
- Install COPYING into docs
- Remove INSTALL from docs
* Sat Apr  7 2012 archie@dellroad.org
- Update to version 1.3.3
* Sat May 14 2011 archie@dellroad.org
- Update to version 1.3.2
* Sun Jul 18 2010 archie@dellroad.org
- Added SUSE_ASNEEDED magic to fix build
